from django.contrib import admin

from .models import GLS, TNT, Chronopost, Ciblex


class GLSAdmin(admin.ModelAdmin):
    list_display = (
        'name',
        'date',
        'points_charges',
        'points_delivered',
        'packages_charges',
        'packages_delivered',
        'avp_relay',
        'shd',
        'eo',
        'pickup_point',
    )
    list_filter = ('date', 'name')


class TNTAdmin(admin.ModelAdmin):
    list_display = (
        'name',
        'date',
        'client_numbers',
        'refused',
        'avp',
        'cad',
        'totals_clients',
        'occasional_abductions',
        'regular_abductions',
        'totals_clients_abductions',
        'hours',
        'breaks',
        'kilometers',
    )
    list_filter = ('date', 'name')


class ChronopostAdmin(admin.ModelAdmin):
    list_display = (
        'name',
        'date',
        'charged_packages',
        'charged_points',
        'including_ip',
        'relay',
        'return_packages',
        'return_points',
        'overdue',
        'anomalies',
        'total_points',
        'hours',
        'breaks',
        'full_km',
    )
    list_filter = ('date', 'name')


class CiblexAdmin(admin.ModelAdmin):
    list_display = (
        'name',
        'date',
        'type',
        'code',
        'nights',
        'days',
        'avp',
        'spare_part',
        'synchro',
        'morning_pickup',
    )
    list_filter = ('date', 'name', 'code')


admin.site.register(GLS, GLSAdmin)
admin.site.register(TNT, TNTAdmin)
admin.site.register(Chronopost, ChronopostAdmin)
admin.site.register(Ciblex, CiblexAdmin)



# Generated by Django 4.2.3 on 2023-07-17 10:33

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name='Chronopost',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
                    ),
                ),
                ('name', models.CharField(max_length=255, verbose_name='Tour Name')),
                ('date', models.DateField(verbose_name='Tour Date')),
                ('charged_packages', models.IntegerField(verbose_name='Charged Packages')),
                ('charged_points', models.IntegerField(verbose_name='Charged Points')),
                ('including_ip', models.IntegerField(verbose_name='Including IP')),
                ('relay', models.IntegerField(verbose_name='Relay')),
                ('return_packages', models.IntegerField(verbose_name='Return Packages')),
                ('return_points', models.IntegerField(verbose_name='Return Points')),
                ('overdue', models.IntegerField(verbose_name='Overdue')),
                ('anomalies', models.IntegerField(verbose_name='Anomalies')),
                ('total_points', models.IntegerField(verbose_name='Total Points')),
                ('hours', models.IntegerField(verbose_name='Hours')),
                ('breaks', models.IntegerField(verbose_name='Breaks')),
                ('full_km', models.IntegerField(verbose_name='Full KM')),
            ],
            options={
                'verbose_name': 'Chronopost',
                'verbose_name_plural': 'Chronopost',
            },
        ),
        migrations.CreateModel(
            name='Ciblex',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
                    ),
                ),
                ('name', models.CharField(max_length=255, verbose_name='Tour Name')),
                ('type', models.CharField(default='LIVRAISONS', max_length=255)),
                (
                    'code',
                    models.CharField(
                        choices=[
                            ('35011', '35011 - RENNES SUD'),
                            ('35020', '35020 - RENNES CHU'),
                            ('35022', '35022 - MONTFORT SUR MEU'),
                            ('35023', '35023 - PACE - ZI LORIENT'),
                        ],
                        max_length=5,
                    ),
                ),
                ('date', models.DateField(verbose_name='Tour Date')),
                ('nights', models.IntegerField(verbose_name='nights')),
                ('days', models.IntegerField(verbose_name='days')),
                ('avp', models.IntegerField(verbose_name='avp')),
                ('spare_part', models.IntegerField(verbose_name='spare part')),
                ('synchro', models.IntegerField(verbose_name='synchro')),
                ('morning_pickup', models.IntegerField(verbose_name='morning pickups')),
            ],
            options={
                'verbose_name': 'Ciblex',
                'verbose_name_plural': 'Ciblex',
            },
        ),
        migrations.CreateModel(
            name='GLS',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
                    ),
                ),
                ('name', models.CharField(max_length=255, verbose_name='Tour Name')),
                ('date', models.DateField(verbose_name='Tour Date')),
                ('points_charges', models.IntegerField(verbose_name='Points Charges')),
                ('points_delivered', models.IntegerField(verbose_name='Points Delivered')),
                ('packages_charges', models.IntegerField(verbose_name='Packages Charges')),
                ('packages_delivered', models.IntegerField(verbose_name='Packages Delivered')),
                ('avp_relay', models.IntegerField(verbose_name='AVP Relay')),
                ('shd', models.IntegerField(verbose_name='SHD')),
                ('eo', models.IntegerField(verbose_name='EO')),
                ('pickup_point', models.IntegerField(verbose_name='Pickup Point')),
            ],
            options={
                'verbose_name': 'GLS',
                'verbose_name_plural': 'GLS',
            },
        ),
        migrations.CreateModel(
            name='TNT',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
                    ),
                ),
                ('name', models.CharField(max_length=255, verbose_name='Tour Name')),
                ('date', models.DateField(verbose_name='Tour Date')),
                ('client_numbers', models.IntegerField(verbose_name='Client numbers')),
                ('refused', models.IntegerField(verbose_name='Refused')),
                ('avp', models.IntegerField(verbose_name='avp')),
                ('cad', models.IntegerField(verbose_name='cad/return')),
                ('totals_clients', models.IntegerField(verbose_name='totals clients')),
                (
                    'occasional_abductions',
                    models.IntegerField(verbose_name='occasional abductions'),
                ),
                ('regular_abductions', models.IntegerField(verbose_name='regular abductions')),
                (
                    'totals_clients_abductions',
                    models.IntegerField(verbose_name='total clients abductions'),
                ),
                ('hours', models.IntegerField(verbose_name='hours')),
                ('breaks', models.IntegerField(verbose_name='breaks')),
                ('kilometers', models.IntegerField(verbose_name='KM/Full')),
            ],
            options={
                'verbose_name': 'TNT - Fedex',
                'verbose_name_plural': 'TNT - Fedex',
            },
        ),
    ]



from django.db import models
from django.utils.translation import gettext_lazy as _


class GLS(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Tour Name'))
    date = models.DateField(verbose_name=_('Tour Date'))
    points_charges = models.IntegerField(verbose_name=_('Points Charges'))
    points_delivered = models.IntegerField(verbose_name=_('Points Delivered'))
    packages_charges = models.IntegerField(verbose_name=_('Packages Charges'))
    packages_delivered = models.IntegerField(verbose_name=_('Packages Delivered'))
    avp_relay = models.IntegerField(verbose_name=_('AVP Relay'))
    shd = models.IntegerField(verbose_name=_('SHD'))
    eo = models.IntegerField(verbose_name=_('EO'))
    pickup_point = models.IntegerField(verbose_name=_('Pickup Point'))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('GLS')
        verbose_name_plural = _('GLS')


class Chronopost(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Tour Name'))
    date = models.DateField(verbose_name=_('Tour Date'))
    charged_packages = models.IntegerField(verbose_name=_('Charged Packages'))
    charged_points = models.IntegerField(verbose_name=_('Charged Points'))
    including_ip = models.IntegerField(verbose_name=_('Including IP'))
    relay = models.IntegerField(verbose_name=_('Relay'))
    return_packages = models.IntegerField(verbose_name=_('Return Packages'))
    return_points = models.IntegerField(verbose_name=_('Return Points'))
    overdue = models.IntegerField(verbose_name=_('Overdue'))
    anomalies = models.IntegerField(verbose_name=_('Anomalies'))
    total_points = models.IntegerField(verbose_name=_('Total Points'))
    hours = models.IntegerField(verbose_name=_('Hours'))
    breaks = models.IntegerField(verbose_name=_('Breaks'))
    full_km = models.IntegerField(verbose_name=_('Full KM'))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Chronopost')
        verbose_name_plural = _('Chronopost')


class TNT(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Tour Name'))
    date = models.DateField(verbose_name=_('Tour Date'))
    client_numbers = models.IntegerField(verbose_name=_('Client numbers'))
    refused = models.IntegerField(verbose_name=_('Refused'))
    avp = models.IntegerField(verbose_name=_('avp'))
    cad = models.IntegerField(verbose_name=_('cad/return'))
    totals_clients = models.IntegerField(verbose_name=_('totals clients'))
    occasional_abductions = models.IntegerField(verbose_name=_('occasional abductions'))
    regular_abductions = models.IntegerField(verbose_name=_('regular abductions'))
    totals_clients_abductions = models.IntegerField(verbose_name=_('total clients abductions'))
    hours = models.IntegerField(verbose_name=_('hours'))
    breaks = models.IntegerField(verbose_name=_('breaks'))
    kilometers = models.IntegerField(verbose_name=_('KM/Full'))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('TNT - Fedex')
        verbose_name_plural = _('TNT - Fedex')


class Ciblex(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Tour Name'))
    type = models.CharField(max_length=255, default="LIVRAISONS")

    CODE_CHOICES = [
        ("35011", "35011 - RENNES SUD"),
        ("35020", "35020 - RENNES CHU"),
        ("35022", "35022 - MONTFORT SUR MEU"),
        ("35023", "35023 - PACE - ZI LORIENT"),
    ]

    code = models.CharField(max_length=5, choices=CODE_CHOICES)
    date = models.DateField(verbose_name=_('Tour Date'))
    nights = models.IntegerField(verbose_name=_('nights'))
    days = models.IntegerField(verbose_name=_('days'))
    avp = models.IntegerField(verbose_name=_('avp'))
    spare_part = models.IntegerField(verbose_name=_('spare part'))
    synchro = models.IntegerField(verbose_name=_('synchro'))
    morning_pickup = models.IntegerField(verbose_name=_('morning pickups'))

    def __str__(self):
        return str(self.date)

    class Meta:
        verbose_name = _('Ciblex')
        verbose_name_plural = _('Ciblex')



from django.contrib import admin
from django.urls import path


admin.site.site_header = "NBTD Transport"
admin.site.site_title = "Portail - NBTD Transport"
admin.site.index_title = "Bienvenue sur le portail des services de NBTD Transport"

urlpatterns = [
    path('', admin.site.urls),
]



from django.contrib import admin

from .models import Event


class EventAdmin(admin.ModelAdmin):
    list_filter = ('date',)

    def changelist_view(self, request, extra_context=None):
        self.date_hierarchy = 'date'
        self.list_display = ('title', 'date')
        return super().changelist_view(request, extra_context)


admin.site.register(Event, EventAdmin)



from django import forms


class DeliveryForm(forms.Form):
    date = forms.DateField()
    points_loaded = forms.IntegerField()
    points_delivered = forms.IntegerField()
    packages_loaded = forms.IntegerField()
    packages_delivered = forms.IntegerField()
    avp_relay = forms.CharField()
    shd = forms.CharField()
    eo = forms.CharField()
    pickup_point = forms.CharField()
